@@ -4,7 +4,6 @@
 #' If the number of trigonometric variables is not specified will search automatically through the model space to identify the best number of trigonometric variables, with the lowest AIC, AICc or BIC value.
 #'
 #' @importFrom stats AIC BIC lm median supsmu
-#' @importFrom MuMIn AICc
 #' @import lubridate
 #'
 #' @param x Numeric vector. Time series to seasonally adjust
@@ -178,7 +177,7 @@ find_outliers=function(x,dates,out.tolerance=3.8,my.AO.list=NULL,H=NULL,my.k_l=N
 
 
         aic0[i,j]=stats::AIC(m)
-        aicc0[i,j]=MuMIn::AICc(m)
+        aicc0[i,j]=stats::AIC(m)+2*length(m$coefficients)*(length(m$coefficients)+1)/(length(m$residuals)-length(m$coefficients)+1)
         bic0[i,j]=stats::BIC(m)
 
       }
